@@ -14,6 +14,8 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+from __future__ import print_function
+from __future__ import absolute_import
 import urllib2 as u2
 import os
 import sys
@@ -28,7 +30,7 @@ from calculate.core.datavars import DataVarsCore
 from calculate.lib.datavars import DataVars
 from calculate.lib.utils.files import readFile
 from suds.client import Client
-from cert_verify import verify, get_CRL
+from .cert_verify import verify, get_CRL
 
 if hasattr(ssl, "PROTOCOL_TLSv1_2"):
     ssl_version = ssl.PROTOCOL_TLSv1_2
@@ -95,7 +97,7 @@ class clientHTTPSConnection(httplib.HTTPSConnection):
             if not filename:
                 return None
         except (IndexError, IOError):
-            print _("Certificate not found on the client's side")
+            print(_("Certificate not found on the client's side"))
             return None
         try:
             with open(self.trusted_path + filename, 'r') as fd:
@@ -103,7 +105,7 @@ class clientHTTPSConnection(httplib.HTTPSConnection):
                 if store_cert == server_cert:
                     return filename
         except IOError:
-            print _("Failed to open the file"), self.trusted_path, filename
+            print(_("Failed to open the file"), self.trusted_path, filename)
         return None
 
     def add_all_ca_cert(self, list_ca_certs):
@@ -139,8 +141,8 @@ class clientHTTPSConnection(httplib.HTTPSConnection):
             md5 = hashlib.md5()
             md5.update(cert)
             md5sum = md5.hexdigest()
-            print "\n================================================="
-            print "md5sum = ", md5sum
+            print("\n=================================================")
+            print("md5sum = ", md5sum)
 
             if not os.path.exists(root_cert_md5):
                 fc = open(root_cert_md5, "w")
@@ -168,7 +170,7 @@ class clientHTTPSConnection(httplib.HTTPSConnection):
                 fc.close()
 
                 if not filename:
-                    print _('Field "CN" not found in the certificate!')
+                    print(_('Field "CN" not found in the certificate!'))
                     return 1
 
                 fd = open(cl_client_cert_dir + '/ca/' + filename, 'w')
@@ -178,10 +180,10 @@ class clientHTTPSConnection(httplib.HTTPSConnection):
                 fa = open(user_root_cert, 'a')
                 fa.write(cert)
                 fa.close()
-                print _("filename = "), filename
-                print _("Certificate added")
+                print(_("filename = "), filename)
+                print(_("Certificate added"))
             else:
-                print _("file containing the CA certificate now exists")
+                print(_("file containing the CA certificate now exists"))
             get_CRL(cl_client_cert_dir + '/')
 
     def add_ca_cert(self, cert, list_ca_certs):
@@ -190,11 +192,11 @@ class clientHTTPSConnection(httplib.HTTPSConnection):
             None, None, self.cert_path))
         cert = client.service.get_ca()
         if cert == '1':
-            print _("Invalid server certificate!")
+            print(_("Invalid server certificate!"))
             sys.exit()
 
         if cert == '2':
-            print _("CA certificate not found on the server")
+            print(_("CA certificate not found on the server"))
             sys.exit()
 
         import OpenSSL
@@ -203,46 +205,46 @@ class clientHTTPSConnection(httplib.HTTPSConnection):
             certobj = OpenSSL.crypto.load_certificate(
                 OpenSSL.SSL.FILETYPE_PEM, cert)
         except (OpenSSL.SSL.Error, IOError):
-            print _("Error. Certificate not added to the trusted list.")
+            print(_("Error. Certificate not added to the trusted list."))
             sys.exit()
-        print '\n' + _("Fingerprint = %s") % certobj.digest('SHA1')
-        print _("Serial number = "), certobj.get_serial_number()
+        print('\n' + _("Fingerprint = %s") % certobj.digest('SHA1'))
+        print(_("Serial number = "), certobj.get_serial_number())
         Issuer = certobj.get_issuer().get_components()
-        print '\n' + _("Issuer")
+        print('\n' + _("Issuer"))
         for i in Issuer:
-            print "%s : %s" % (i[0], i[1])
+            print("%s : %s" % (i[0], i[1]))
         Subject = certobj.get_subject().get_components()
-        print '\n' + _("Subject")
+        print('\n' + _("Subject"))
         for subj in Subject:
-            print "%s : %s" % (subj[0], subj[1])
+            print("%s : %s" % (subj[0], subj[1]))
         ans = raw_input(_("Add the CA certificate to trusted? y/[n]:"))
         if ans.lower() in ['y', 'yes']:
             list_ca_certs.append(cert)
             self.add_all_ca_cert(list_ca_certs)
         else:
-            print _("Certificate not added to trusted")
+            print(_("Certificate not added to trusted"))
         sys.exit()
 
     # add certificate server in trusted
     def add_server_cert(self, cert):
         import OpenSSL
 
-        print _("Untrusted server certificate!")
+        print(_("Untrusted server certificate!"))
         certobj = OpenSSL.crypto.load_certificate(OpenSSL.SSL.FILETYPE_PEM,
                                                   cert)
-        print '\n' + _("Fingerprint = %s") % certobj.digest('SHA1')
-        print _("Serial number = "), certobj.get_serial_number()
+        print('\n' + _("Fingerprint = %s") % certobj.digest('SHA1'))
+        print(_("Serial number = "), certobj.get_serial_number())
         Issuer = certobj.get_issuer().get_components()
-        print '\n' + _("Issuer")
+        print('\n' + _("Issuer"))
         for i in Issuer:
-            print "%s : %s" % (i[0], i[1])
+            print("%s : %s" % (i[0], i[1]))
         Subject = certobj.get_subject().get_components()
-        print '\n' + _("Subject")
+        print('\n' + _("Subject"))
         for item in Subject:
-            print "%s : %s" % (item[0], item[1])
+            print("%s : %s" % (item[0], item[1]))
 
-        print '\n' + _('Add this server certificate to trusted (s) or')
-        print _('Try to add the CA and root certificates to trusted (c) or')
+        print('\n' + _('Add this server certificate to trusted (s) or'))
+        print(_('Try to add the CA and root certificates to trusted (c) or'))
         choice = raw_input(_("Quit (q)? s/c/[q]: "))
         if choice.lower() in ['s', 'c']:
             # self.sock = ssl.wrap_socket(sock)
@@ -287,10 +289,10 @@ class clientHTTPSConnection(httplib.HTTPSConnection):
                 try:
                     os.makedirs(root_cert_dir)
                 except OSError:
-                    print _("Error creating directory %s") % root_cert_dir
+                    print(_("Error creating directory %s") % root_cert_dir)
                     sys.exit()
 
-            print '\n' + _("Add the CA and root certificates")
+            print('\n' + _("Add the CA and root certificates"))
             self.list_ca_certs = []
             self.add_ca_cert(cert, self.list_ca_certs)
             sys.exit()
@@ -315,7 +317,7 @@ class clientHTTPSConnection(httplib.HTTPSConnection):
 
         try:
             if ssl_version is None:
-                print _("SSL library is not support TLSv1_2")
+                print(_("SSL library is not support TLSv1_2"))
                 self.sock.close()
                 return 2
 
@@ -355,7 +357,7 @@ class clientHTTPSConnection(httplib.HTTPSConnection):
         if HTTPSClientCertTransport.filename:
             try:
                 if ssl_version is None:
-                    print _("SSL library is not support TLSv1_2")
+                    print(_("SSL library is not support TLSv1_2"))
                     HTTPSClientCertTransport.filename = None
                     self.sock.close()
                     return 1
@@ -369,7 +371,7 @@ class clientHTTPSConnection(httplib.HTTPSConnection):
                 ssl.DER_cert_to_PEM_cert(dercert_after_connect)
                 return 0
             except Exception as e:
-                print e
+                print(e)
                 HTTPSClientCertTransport.filename = None
                 return 1
         else:
