@@ -14,8 +14,10 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+from __future__ import print_function
+from __future__ import absolute_import
 import sys
-from function import get_sid
+from .function import get_sid
 
 _ = lambda x: x
 from calculate.lib.cl_lang import setLocalTranslate
@@ -33,10 +35,10 @@ def client_sid(sid, client, cert_id):
     fi.write(sid)
     fi.close()
     if new_sid[0][1] == 1:
-        print _(" New session")
+        print(_(" New session"))
     else:
-        print _(" Old session")
-    print _(" Your session ID = %s") % sid
+        print(_(" Old session"))
+    print(_(" Your session ID = %s") % sid)
 
 
 def client_del_sid(client):
@@ -46,22 +48,22 @@ def client_del_sid(client):
         s = client.service.del_sid(sid)
 
         if s[0][0] == "-1":
-            print _("No access to the file!")
+            print(_("No access to the file!"))
             return -1
         if s[0][0] == "1":
-            print _("Failed to obtain the certificate data!")
+            print(_("Failed to obtain the certificate data!"))
             return -2
         if s[0][0] == "Permission denied":
-            print _("%s: Permission denied") % s[1][1]
+            print(_("%s: Permission denied") % s[1][1])
             return -3
 
         if s[0][0] == '0':
             fi = open(client.SID_FILE, 'w')
             fi.write('0')
             fi.close()
-            print _("SID deleted!")
+            print(_("SID deleted!"))
     except Exception:
-        print _("Failed to delete the SID on the server")
+        print(_("Failed to delete the SID on the server"))
         return 1
     return 0
 
@@ -70,27 +72,27 @@ def sid_inf(client, sid):
     """ get information about selected session """
     s = client.service.sid_info(sid)
     if s[0][0] == "-1":
-        print _("Session not registered on the server!")
+        print(_("Session not registered on the server!"))
         return -1
     if s[0][0] == "-2":
-        print _("Failed to obtain the certificate data!")
+        print(_("Failed to obtain the certificate data!"))
         return -2
     if s[0][0] == "Permission denied":
-        print _("%s: Permission denied") % s[0][1]
+        print(_("%s: Permission denied") % s[0][1])
         return -3
 
-    print "============================"
-    print '\n' + _(u"Session number: %s") % sid
+    print("============================")
+    print('\n' + _(u"Session number: %s") % sid)
     if s[0][5] == "0":
-        print _(u"Session active")
+        print(_(u"Session active"))
     else:
-        print _(u"Session inactive")
-    print _(u"Certificate number: %s") % s[0][0]
-    print _(u"Certificate issued on %s") % s[0][1]
-    print _(u"IP: %s") % s[0][2]
-    print _(u"MAC: %s") % s[0][3]
-    print _(u"Client type: %s") % s[0][4]
-    print "============================"
+        print(_(u"Session inactive"))
+    print(_(u"Certificate number: %s") % s[0][0])
+    print(_(u"Certificate issued on %s") % s[0][1])
+    print(_(u"IP: %s") % s[0][2])
+    print(_(u"MAC: %s") % s[0][3])
+    print(_(u"Client type: %s") % s[0][4])
+    print("============================")
     return 0
 
 
@@ -100,14 +102,14 @@ def client_session_info(client):
     try:
         sid = int(sid)
     except ValueError:
-        print _("Invalid SID")
+        print(_("Invalid SID"))
         return 1
     try:
         if sid > 0:
             sid_inf(client, sid)
         else:
-            print _("Please enter a correct SID")
+            print(_("Please enter a correct SID"))
     except Exception:
-        print _("Failed to get data")
+        print(_("Failed to get data"))
         return 1
     return 0
